    Mac OS X            	   2                                             ATTR ?                             %   com.macromates.bookmarked_lines    
   $  com.macromates.caret   1     com.macromates.foldings  xR Cs0000L,!.M {
    column = 52;
    line = 395;
}xA
0н,`3i.TwŻWPHK&daHUk{:G
0W6,P@  20T2Jć<%^J@PT&OE(A&f~^|y4"QL(F}RٗXđr